@@ -34,6 +34,7 @@ fit.adapt.random2byclass.randomLCA <- function(outcomes,freq,nclass=2,initoutcom
 		# browser()
         ill2 <- log(rowSums(ill))
         totalll <- sum(ill2*freq)
+		if (is.nan(totalll) || is.infinite(totalll)) totalll <- -1.0*.Machine$double.xmax
         if (calcfitted) {
        		fitted <- exp(ill2)*sum(ifelse(apply(outcomes,1,function(x) 
        			any(is.na(x))),0,freq))*
@@ -87,6 +88,7 @@ fit.adapt.random2byclass.randomLCA <- function(outcomes,freq,nclass=2,initoutcom
                 
 		adaptive <- TRUE
 		prevll <- -Inf
+		nadaptive <- 0
         while(adaptive) {
             # need to do an optimisation on the other parameters
             fitresults <- fitparams(classx,outcomex,lambdacoef,ltaucoef,
@@ -114,6 +116,8 @@ fit.adapt.random2byclass.randomLCA <- function(outcomes,freq,nclass=2,initoutcom
         	adaptive <- (abs((currll-optll)/currll)>1.0e-7) ||
         		(abs((currll-prevll)/currll)>1.0e-7)
         	if ((prevll-currll)/abs(currll) > 1.0e-4) stop("divergence - increase quadrature points")
+        	nadaptive <- nadaptive+1
+        	if (nadaptive > 200) stop("too many adaptive iterations - increase quadrature points")
         	prevll <- currll
        }
         fitresults <- fitparams(classx,outcomex,lambdacoef,ltaucoef,
@@ -216,6 +220,7 @@ fit.adapt.random2byclass.randomLCA <- function(outcomes,freq,nclass=2,initoutcom
 						}
 					
 					ll <- -(sum(log(allprob))+sum(dnorm(beta,mean=0,sd=1,log=TRUE)))
+					if (is.nan(ll) || is.infinite(ll)) ll <- 1.0*.Machine$double.xmax
 				  return(ll)
 				}
 			  beta <- rep(0,1+nlevel2)
